==> webpdf-wsclient-10.0.1-sources.jar: net/webpdf/wsclient/schema/operation/ConverterTemplateType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p165541_="https://jakarta.ee/xml/ns/jaxb" xmlns:p356920_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Can be used to define settings for file formats for which a template is required for conversion. As of this writing, these settings apply to the following file formats:&#13;
 *                     &lt;ul&gt;&lt;li&gt;MIME mail (eml)&lt;/li&gt;&lt;li&gt;Outlook message (msg)&lt;/li&gt;&lt;li&gt;iCalendar (ics) / vCalendar (vcs)&lt;/li&gt;&lt;li&gt;vCard (vcf)&lt;/li&gt;&lt;li&gt;Serial Vector Format (svg)&lt;/li&gt;&lt;li&gt;Text document (txt)&lt;/li&gt;&lt;/ul&gt;&#13;
 *                     In addition, you can replace the default template with a custom template of your own in "file". You can also use your own variables in this custom template. These variables would then need to be passed with a JSON structure (Base64-encoded) in "data".&#13;
 *                 &lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for ConverterTemplateType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="ConverterTemplateType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}TemplateType">
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterTemplateType")
public class ConverterTemplateType
    extends TemplateType
{


}

==> webpdf-wsclient-10.0.2-sources.jar: net/webpdf/wsclient/schema/operation/ConverterTemplateType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p532746_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p882137_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Can be used to define settings for file formats for which a template is required for conversion. As of this writing, these settings apply to the following file formats:&#13;
 *                     &lt;ul&gt;&lt;li&gt;MIME mail (eml)&lt;/li&gt;&lt;li&gt;Outlook message (msg)&lt;/li&gt;&lt;li&gt;iCalendar (ics) / vCalendar (vcs)&lt;/li&gt;&lt;li&gt;vCard (vcf)&lt;/li&gt;&lt;li&gt;Serial Vector Format (svg)&lt;/li&gt;&lt;li&gt;Text document (txt)&lt;/li&gt;&lt;/ul&gt;&#13;
 *                     In addition, you can replace the default template with a custom template of your own in "file". You can also use your own variables in this custom template. These variables would then need to be passed with a JSON structure (Base64-encoded) in "data".&#13;
 *                 &lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for ConverterTemplateType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="ConverterTemplateType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}TemplateType">
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterTemplateType")
public class ConverterTemplateType
    extends TemplateType
{


}
